pub fn get_write_protocols_to_try(
git_repo: &Repo,
server_url: &CloneUrl,
decoded_nostr_url: &NostrUrlDecoded,
is_grasp_server: bool,
) -> Vec<ServerProtocol>Expand description
get an ordered vector of server protocols to attempt
pub fn get_write_protocols_to_try(
git_repo: &Repo,
server_url: &CloneUrl,
decoded_nostr_url: &NostrUrlDecoded,
is_grasp_server: bool,
) -> Vec<ServerProtocol>get an ordered vector of server protocols to attempt